==> cscec5b-wzxt-api-3.0.0-20210319.064408-162-sources.jar: com/ejianc/business/wzxt/vo/ExitApplyDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
public class ExitApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pId; // 退场申请单ID
    private Integer referType; // 参照类型(1在场周转材2材料库)
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 型号
    private String measureUnit; // 计量单位
    private java.math.BigDecimal onRentNum; // 在租数量
    private java.math.BigDecimal applyExitNum; // 申请退场数量
    private java.math.BigDecimal exitedNum; // 已退场数量
    private java.util.Date offRentDate; // 止租日
    private String memo; // 备注
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    

    /**
     * 退场申请单ID
     */
    public Long getPId() {
        return pId;
    }

    /**
     * 退场申请单ID
     */
    public void setPId(Long pId) {
        this.pId = pId;
    }
    /**
     * 参照类型(1在场周转材2材料库)
     */
    public Integer getReferType() {
        return referType;
    }

    /**
     * 参照类型(1在场周转材2材料库)
     */
    public void setReferType(Integer referType) {
        this.referType = referType;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资来源主键
     */
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getMeasureUnit() {
        return measureUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasureUnit(String measureUnit) {
        this.measureUnit = measureUnit;
    }
    /**
     * 在租数量
     */
    public java.math.BigDecimal getOnRentNum() {
        return onRentNum;
    }

    /**
     * 在租数量
     */
    public void setOnRentNum(java.math.BigDecimal onRentNum) {
        this.onRentNum = onRentNum;
    }
    /**
     * 申请退场数量
     */
    public java.math.BigDecimal getApplyExitNum() {
        return applyExitNum;
    }

    /**
     * 申请退场数量
     */
    public void setApplyExitNum(java.math.BigDecimal applyExitNum) {
        this.applyExitNum = applyExitNum;
    }
    /**
     * 已退场数量
     */
    public java.math.BigDecimal getExitedNum() {
        return exitedNum;
    }

    /**
     * 已退场数量
     */
    public void setExitedNum(java.math.BigDecimal exitedNum) {
        this.exitedNum = exitedNum;
    }
    /**
     * 止租日
     */
    public java.util.Date getOffRentDate() {
        return offRentDate;
    }

    /**
     * 止租日
     */
    public void setOffRentDate(java.util.Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }
    
}

==> cscec5b-wzxt-api-3.0.0-20210330.092239-221-sources.jar: com/ejianc/business/wzxt/vo/ExitApplyDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
public class ExitApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pId; // 退场申请单ID
    private Integer referType; // 参照类型(1在场周转材2材料库)
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private String spec; // 型号
    private String unit; // 计量单位
    private java.math.BigDecimal onRentNum; // 在租数量
    private java.math.BigDecimal applyExitNum; // 申请退场数量
    private java.math.BigDecimal exitedNum; // 已退场数量
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date offRentDate; // 止租日
    private String memo; // 备注
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    

    /**
     * 退场申请单ID
     */
    public Long getPId() {
        return pId;
    }

    /**
     * 退场申请单ID
     */
    public void setPId(Long pId) {
        this.pId = pId;
    }
    /**
     * 参照类型(1在场周转材2材料库)
     */
    public Integer getReferType() {
        return referType;
    }

    /**
     * 参照类型(1在场周转材2材料库)
     */
    public void setReferType(Integer referType) {
        this.referType = referType;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资来源主键
     */
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    /**
     * 在租数量
     */
    public java.math.BigDecimal getOnRentNum() {
        return onRentNum;
    }

    /**
     * 在租数量
     */
    public void setOnRentNum(java.math.BigDecimal onRentNum) {
        this.onRentNum = onRentNum;
    }
    /**
     * 申请退场数量
     */
    public java.math.BigDecimal getApplyExitNum() {
        return applyExitNum;
    }

    /**
     * 申请退场数量
     */
    public void setApplyExitNum(java.math.BigDecimal applyExitNum) {
        this.applyExitNum = applyExitNum;
    }
    /**
     * 已退场数量
     */
    public java.math.BigDecimal getExitedNum() {
        return exitedNum;
    }

    /**
     * 已退场数量
     */
    public void setExitedNum(java.math.BigDecimal exitedNum) {
        this.exitedNum = exitedNum;
    }
    /**
     * 止租日
     */
    public java.util.Date getOffRentDate() {
        return offRentDate;
    }

    /**
     * 止租日
     */
    public void setOffRentDate(java.util.Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }
    
}
